Module time

Module time 

Structs

Interval
IntervalTypeError

Enums

AlignmentUnit
Used to keep track of the smallest unit provided, so that we can line up windows (eg. at the start of the hour, week, year, …)
IntervalSize

Traits

TryIntoInterval