pub enum AlignmentUnit {
Unaligned,
Millisecond,
Second,
Minute,
Hour,
Day,
Week,
Month,
Year,
}Expand description
Used to keep track of the smallest unit provided, so that we can line up windows (eg. at the start of the hour, week, year, …)
Variants
Implementations
Sourceimpl AlignmentUnit
impl AlignmentUnit
Sourcepub fn align_timestamp(&self, timestamp: i64) -> i64
pub fn align_timestamp(&self, timestamp: i64) -> i64
Floors a UTC timestamp in milliseconds since Unix epoch to the nearest alignment unit.