TryIntoTime

Trait TryIntoTime 

pub trait TryIntoTime {
    // Required method
    fn try_into_time(self) -> Result<i64, ParseTimeError>;
}

Required Methods

Implementations on Foreign Types

Source

impl TryIntoTime for &str

Source

fn try_into_time(self) -> Result<i64, ParseTimeError>

Tries to parse the timestamp as RFC3339 and then as ISO 8601 with local format and all fields mandatory except for milliseconds and allows replacing the T with a space

Implementors