Module time
raphtory_
core
0.17.0
Module time
Module Items
Structs
Enums
Traits
In raphtory_
core::
utils
raphtory_core
::
utils
Module
time
Structs

Interval
Interval
Type
Error
Enums

Alignment
Unit
Used to keep track of the smallest unit provided, so that we can line up windows (eg. at the start of the hour, week, year, …)
Interval
Size
Traits

TryInto
Interval