Module time

Module time 

Structs

Interval
IntervalTypeError

Enums

AlignmentUnit
Used to keep track of the smallest unit provided, so that we can line up windows (eg. at the start of the hour, week, year, …)
InputTime
Used to handle automatic injection of secondary index if not explicitly provided
IntervalSize
ParseTimeError

Traits

IntoTime
IntoTimeWithFormat
TryIntoInputTime
TryIntoInterval
TryIntoTime