Structs
Enums
- Alignment
Unit - Used to keep track of the smallest unit provided, so that we can line up windows (eg. at the start of the hour, week, year, …)
- Input
Time - Used to handle automatic injection of secondary index if not explicitly provided
- Interval
Size - Parse
Time Error