pub struct Interval {
pub alignment_unit: Option<AlignmentUnit>,
pub size: IntervalSize,
}Fields
alignment_unit: Option<AlignmentUnit>Used if the IntervalSize is Temporal, keeps track of the smallest unit passed to line up windows.
(eg. at the start of the hour, week, year, …). If the IntervalSize is discrete, this is None.
size: IntervalSizeThe interval.
Implementations
Sourceimpl Interval
impl Interval
Sourcepub fn to_millis(&self) -> Option<u64>
pub fn to_millis(&self) -> Option<u64>
Return an option because there might be no exact translation to millis for some intervals
pub fn discrete(num: u64) -> Self
pub fn milliseconds(ms: i64) -> Self
pub fn seconds(seconds: i64) -> Self
pub fn minutes(minutes: i64) -> Self
pub fn hours(hours: i64) -> Self
pub fn days(days: i64) -> Self
pub fn weeks(weeks: i64) -> Self
pub fn months(months: i64) -> Self
pub fn years(years: i64) -> Self
pub fn and(&self, other: &Self) -> Result<Self, IntervalTypeError>